[![DL stat](https://img.shields.io/pypi/v/mypdns.png)](https://pypi.org/project/mypdns)
[![DL stat](https://pepy.tech/badge/mypdns)](https://pepy.tech/project/mypdns)
[![DL stat month](https://pepy.tech/badge/mypdns/month)](https://pepy.tech/project/mypdns)
[![DL stat Week](https://pepy.tech/badge/mypdns/week)](https://pepy.tech/project/mypdns)


Namespace Reservation for the [mypdns.org](https://mypdns.org/python/mypdns) project
